@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,12 +22,13 @@
 #include <ofono/modem.h>
 #include <ofono/gprs-context.h>
 
+#include <drivers/atmodem/atutil.h>
+#include <drivers/atmodem/vendor.h>
+
 #include "gatchat.h"
 #include "gatresult.h"
 #include "gatrawip.h"
 
-#include "ifxmodem.h"
-
 #define TUN_DEV "/dev/net/tun"
 
 #define STATIC_IP_NETMASK "255.255.255.255"
@@ -354,6 +341,9 @@ static void cgcontrdp_cb(gboolean ok, GAtResult *result, gpointer user_data)
 
 	DBG("DNS: %s, %s\n", gcd->dns1, gcd->dns2);
 
+	if (gw)
+		l_strlcpy(gcd->gateway, gw, sizeof(gcd->gateway));
+
 	if (gcd->proto == OFONO_GPRS_PROTO_IP) {
 		if (!laddrnetmask ||
 			at_util_get_ipv4_address_and_netmask(laddrnetmask,
@@ -391,9 +381,6 @@ static void cgcontrdp_cb(gboolean ok, GAtResult *result, gpointer user_data)
 						IPV6_DEFAULT_PREFIX_LEN);
 	}
 
-	if (gw)
-		l_strlcpy(gcd->gateway, gw, sizeof(gcd->gateway));
-
 	gcd->state = STATE_ACTIVE;
 
 	DBG("address: %s\n", gcd->address);
@@ -737,7 +724,6 @@ static void ifx_gprs_context_remove(struct ofono_gprs_context *gc)
 }
 
 static const struct ofono_gprs_context_driver driver = {
-	.name			= "ifxmodem",
 	.probe			= ifx_gprs_context_probe,
 	.remove			= ifx_gprs_context_remove,
 	.activate_primary	= ifx_gprs_activate_primary,
@@ -746,12 +732,4 @@ static const struct ofono_gprs_context_driver driver = {
 	.detach_shutdown	= ifx_gprs_detach_shutdown
 };
 
-void ifx_gprs_context_init(void)
-{
-	ofono_gprs_context_driver_register(&driver);
-}
-
-void ifx_gprs_context_exit(void)
-{
-	ofono_gprs_context_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(gprs_context, ifxmodem, &driver)
