@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2017  Jonas Bonn
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2017  Jonas Bonn. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,8 +15,6 @@
 #include <string.h>
 #include <errno.h>
 
-#include <glib.h>
-
 #include <ofono/log.h>
 #include <ofono/modem.h>
 #include <ofono/netmon.h>
@@ -90,7 +74,7 @@ static void get_rssi_cb(struct qmi_result *result, void *user_data)
 	/* RSSI */
 	rssi = qmi_result_get(result, 0x11, &len);
 	if (rssi) {
-		num = GUINT16_FROM_LE(rssi->count);
+		num = L_LE16_TO_CPU(rssi->count);
 		for (i = 0; i < num; i++) {
 			DBG("RSSI: %hhu on RAT %hhd",
 				rssi->info[i].rssi,
@@ -127,14 +111,14 @@ static void get_rssi_cb(struct qmi_result *result, void *user_data)
 	/* Bit error rate */
 	ber = qmi_result_get(result, 0x15, &len);
 	if (ber) {
-		num = GUINT16_FROM_LE(ber->count);
+		num = L_LE16_TO_CPU(ber->count);
 		for (i = 0; i < ber->count; i++) {
 			DBG("Bit error rate: %hu on RAT %hhd",
-				GUINT16_FROM_LE(ber->info[i].rate),
+				L_LE16_TO_CPU(ber->info[i].rate),
 				ber->info[i].rat);
 		}
 
-		props.ber = GUINT16_FROM_LE(ber->info[0].rate);
+		props.ber = L_LE16_TO_CPU(ber->info[0].rate);
 		if (props.ber > 7)
 			props.ber = -1;
 	} else {
@@ -203,12 +187,12 @@ static void qmi_netmon_request_update(struct ofono_netmon *netmon,
 	qmi_param_append_uint16(param, 0x10, 255);
 
 	if (qmi_service_send(data->nas, QMI_NAS_GET_SIGNAL_STRENGTH, param,
-					get_rssi_cb, cbd, g_free) > 0)
+					get_rssi_cb, cbd, l_free) > 0)
 		return;
 
 	qmi_param_free(param);
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void create_nas_cb(struct qmi_service *service, void *user_data)
@@ -224,7 +208,7 @@ static void create_nas_cb(struct qmi_service *service, void *user_data)
 		return;
 	}
 
-	nmd->nas = qmi_service_ref(service);
+	nmd->nas = service;
 
 	ofono_netmon_register(netmon);
 }
@@ -237,7 +221,7 @@ static int qmi_netmon_probe(struct ofono_netmon *netmon,
 
 	DBG("");
 
-	nmd = g_new0(struct netmon_data, 1);
+	nmd = l_new(struct netmon_data, 1);
 
 	ofono_netmon_set_data(netmon, nmd);
 
@@ -255,9 +239,9 @@ static void qmi_netmon_remove(struct ofono_netmon *netmon)
 
 	ofono_netmon_set_data(netmon, NULL);
 
-	qmi_service_unref(nmd->nas);
+	qmi_service_free(nmd->nas);
 
-	g_free(nmd);
+	l_free(nmd);
 }
 
 static const struct ofono_netmon_driver driver = {
