@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2011-2012  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2011-2012  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,8 +16,7 @@
 #include "qmi.h"
 #include "nas.h"
 #include "dms.h"
-
-#include "qmimodem.h"
+#include "util.h"
 
 struct settings_data {
 	struct qmi_service *nas;
@@ -86,8 +71,8 @@ static void qmi_query_rat_mode(struct ofono_radio_settings *rs,
 	DBG("");
 
 	if (qmi_service_send(data->nas,
-				QMI_NAS_GET_SYSTEM_SELECTION_PREF, NULL,
-				get_system_selection_pref_cb, cbd, g_free) > 0)
+				QMI_NAS_GET_SYSTEM_SELECTION_PREFERENCE, NULL,
+				get_system_selection_pref_cb, cbd, l_free) > 0)
 		return;
 
 	CALLBACK_WITH_FAILURE(cb, -1, data);
@@ -139,22 +124,18 @@ static void qmi_set_rat_mode(struct ofono_radio_settings *rs, unsigned int mode,
 	}
 
 	param = qmi_param_new();
-	if (!param) {
-		CALLBACK_WITH_FAILURE(cb, user_data);
-		return;
-	}
 
 	qmi_param_append_uint16(param, QMI_NAS_PARAM_SYSTEM_SELECTION_PREF_MODE,
 			pref);
 
 	if (qmi_service_send(data->nas,
-				QMI_NAS_SET_SYSTEM_SELECTION_PREF, param,
-				set_system_selection_pref_cb, cbd, g_free) > 0)
+				QMI_NAS_SET_SYSTEM_SELECTION_PREFERENCE, param,
+				set_system_selection_pref_cb, cbd, l_free) > 0)
 		return;
 
 	qmi_param_free(param);
 	CALLBACK_WITH_FAILURE(cb, user_data);
-	g_free(cbd);
+	l_free(cbd);
 }
 
 static void get_caps_cb(struct qmi_result *result, void *user_data)
@@ -209,11 +190,11 @@ static void qmi_query_available_rats(struct ofono_radio_settings *rs,
 		goto error;
 
 	if (qmi_service_send(rsd->dms, QMI_DMS_GET_CAPS, NULL,
-					get_caps_cb, cbd, g_free) > 0)
+					get_caps_cb, cbd, l_free) > 0)
 		return;
 
 error:
-	g_free(cbd);
+	l_free(cbd);
 	CALLBACK_WITH_FAILURE(cb, -1, data);
 }
 
@@ -227,7 +208,7 @@ static void create_dms_cb(struct qmi_service *service, void *user_data)
 	if (!service)
 		return;
 
-	data->dms = qmi_service_ref(service);
+	data->dms = service;
 }
 
 static void create_nas_cb(struct qmi_service *service, void *user_data)
@@ -249,7 +230,7 @@ static void create_nas_cb(struct qmi_service *service, void *user_data)
 		return;
 	}
 
-	data->nas = qmi_service_ref(service);
+	data->nas = service;
 
 	ofono_radio_settings_register(rs);
 }
@@ -262,7 +243,7 @@ static int qmi_radio_settings_probe(struct ofono_radio_settings *rs,
 
 	DBG("");
 
-	data = g_new0(struct settings_data, 1);
+	data = l_new(struct settings_data, 1);
 
 	ofono_radio_settings_set_data(rs, data);
 
@@ -282,18 +263,13 @@ static void qmi_radio_settings_remove(struct ofono_radio_settings *rs)
 
 	ofono_radio_settings_set_data(rs, NULL);
 
-	qmi_service_unregister_all(data->dms);
-	qmi_service_unref(data->dms);
+	qmi_service_free(data->dms);
+	qmi_service_free(data->nas);
 
-	qmi_service_unregister_all(data->nas);
-
-	qmi_service_unref(data->nas);
-
-	g_free(data);
+	l_free(data);
 }
 
 static const struct ofono_radio_settings_driver driver = {
-	.name		= "qmimodem",
 	.probe		= qmi_radio_settings_probe,
 	.remove		= qmi_radio_settings_remove,
 	.set_rat_mode	= qmi_set_rat_mode,
@@ -301,12 +277,4 @@ static const struct ofono_radio_settings_driver driver = {
 	.query_available_rats = qmi_query_available_rats,
 };
 
-void qmi_radio_settings_init(void)
-{
-	ofono_radio_settings_driver_register(&driver);
-}
-
-void qmi_radio_settings_exit(void)
-{
-	ofono_radio_settings_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(radio_settings, qmimodem, &driver)
