@@ -1,23 +1,9 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2011  BMW Car IT GmbH
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2011  BMW Car IT GmbH. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_HANDSFREE_H
@@ -42,7 +28,6 @@ typedef void (*ofono_handsfree_cnum_query_cb_t)(const struct ofono_error *error,
 				void *data);
 
 struct ofono_handsfree_driver {
-	const char *name;
 	int (*probe)(struct ofono_handsfree *hf, unsigned int vendor,
 			void *data);
 	void (*remove)(struct ofono_handsfree *hf);
@@ -80,10 +65,6 @@ void ofono_handsfree_hf_indicator_active_notify(struct ofono_handsfree *hf,
 void ofono_handsfree_battchg_notify(struct ofono_handsfree *hf,
 					unsigned char level);
 
-int ofono_handsfree_driver_register(const struct ofono_handsfree_driver *d);
-void ofono_handsfree_driver_unregister(
-			const struct ofono_handsfree_driver *d);
-
 struct ofono_handsfree *ofono_handsfree_create(struct ofono_modem *modem,
 			unsigned int vendor, const char *driver, void *data);
 
