@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies)
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies).
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifndef __OFONO_RADIO_SETTINGS_H
@@ -85,7 +71,6 @@ typedef void (*ofono_radio_settings_available_rats_query_cb_t)(
 						void *data);
 
 struct ofono_radio_settings_driver {
-	const char *name;
 	int (*probe)(struct ofono_radio_settings *rs, unsigned int vendor,
 			void *data);
 	void (*remove)(struct ofono_radio_settings *rs);
@@ -115,11 +100,6 @@ struct ofono_radio_settings_driver {
 			void *data);
 };
 
-int ofono_radio_settings_driver_register(
-				const struct ofono_radio_settings_driver *d);
-void ofono_radio_settings_driver_unregister(
-				const struct ofono_radio_settings_driver *d);
-
 struct ofono_radio_settings *ofono_radio_settings_create(
 						struct ofono_modem *modem,
 						unsigned int vendor,
