@@ -1,22 +1,8 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include <glib.h>
@@ -26,11 +12,9 @@
 
 #include <ofono/types.h>
 
+const struct l_settings *__ofono_get_config(void);
 void __ofono_exit(void);
 
-int __ofono_manager_init(void);
-void __ofono_manager_cleanup(void);
-
 int __ofono_handsfree_audio_manager_init(void);
 void __ofono_handsfree_audio_manager_cleanup(void);
 
@@ -97,6 +81,25 @@ gboolean __ofono_watchlist_remove_item(struct ofono_watchlist *watchlist,
 					unsigned int id);
 void __ofono_watchlist_free(struct ofono_watchlist *watchlist);
 
+struct ofono_module_desc {
+	const char *name;
+	int (*init)(void);
+	void (*exit)(void);
+} __attribute__((aligned(8)));
+
+#define OFONO_MODULE(name, init, exit)					\
+	_Pragma("GCC diagnostic push")					\
+	_Pragma("GCC diagnostic ignored \"-Wattributes\"")		\
+	static struct ofono_module_desc __ofono_module_ ## name		\
+		__attribute__((used, retain, section("__ofono_module"),	\
+			       aligned(8))) = {				\
+			#name, init, exit				\
+		};							\
+	_Pragma("GCC diagnostic pop")
+
+int __ofono_modules_init(void);
+void __ofono_modules_cleanup(void);
+
 #include <ofono/plugin.h>
 
 int __ofono_plugin_init(const char *pattern, const char *exclude);
@@ -132,7 +135,7 @@ enum ofono_atom_type {
 	OFONO_ATOM_TYPE_SSN,
 	OFONO_ATOM_TYPE_MESSAGE_WAITING,
 	OFONO_ATOM_TYPE_CBS,
-	OFONO_ATOM_TYPES_CALL_VOLUME,
+	OFONO_ATOM_TYPE_CALL_VOLUME,
 	OFONO_ATOM_TYPE_GPRS,
 	OFONO_ATOM_TYPE_GPRS_CONTEXT,
 	OFONO_ATOM_TYPE_RADIO_SETTINGS,
@@ -217,6 +220,42 @@ gboolean __ofono_modem_remove_atom_watch(struct ofono_modem *modem,
 
 void __ofono_atom_free(struct ofono_atom *atom);
 
+const void *__ofono_driver_builtin_find(const char *name,
+				const struct ofono_driver_desc *start,
+				const struct ofono_driver_desc *stop);
+
+#define OFONO_DEFINE_ATOM_CREATE(type, atom_type, ...)			\
+extern struct ofono_driver_desc __start___ ## type[];			\
+extern struct ofono_driver_desc __stop___ ## type[];			\
+									\
+struct ofono_ ## type *ofono_ ## type ##_create(			\
+				struct ofono_modem *modem,		\
+				unsigned int vendor, const char *driver,\
+				void *data)				\
+{									\
+	const struct ofono_ ## type ## _driver *drv =			\
+		__ofono_driver_builtin_find(driver,			\
+				__start___ ## type,			\
+				__stop___ ## type);			\
+	struct ofono_ ## type *atom;					\
+									\
+	if (!drv || !drv->probe)					\
+		return NULL;						\
+									\
+	atom = g_new0(struct ofono_ ##type, 1);				\
+	atom->atom = __ofono_modem_add_atom(modem, atom_type,		\
+				type ##_remove, atom);			\
+	__VA_ARGS__							\
+									\
+	if (drv->probe(atom, vendor, data) < 0)	{			\
+		ofono_ ## type ##_remove(atom);				\
+		return NULL;						\
+	}								\
+									\
+	atom->driver = drv;						\
+	return atom;							\
+}
+
 typedef void (*ofono_modemwatch_cb_t)(struct ofono_modem *modem,
 					gboolean added, void *data);
 void __ofono_modemwatch_init(void);
@@ -527,18 +566,13 @@ void __ofono_nettime_probe_drivers(struct ofono_modem *modem);
 void __ofono_nettime_info_received(struct ofono_modem *modem,
 					struct ofono_network_time *info);
 
-#include <ofono/cdma-voicecall.h>
-#include <ofono/cdma-connman.h>
 #include <ofono/sim-auth.h>
 
-#include <ofono/gprs-provision.h>
-ofono_bool_t __ofono_gprs_provision_get_settings(const char *mcc,
+struct provision_db_entry;
+bool __ofono_provision_get_settings(const char *mcc,
 				const char *mnc, const char *spn,
-				struct ofono_gprs_provision_data **settings,
-				int *count);
-void __ofono_gprs_provision_free_settings(
-				struct ofono_gprs_provision_data *settings,
-				int count);
+				struct provision_db_entry **settings,
+				size_t *count);
 
 #include <ofono/emulator.h>
 
@@ -554,11 +588,6 @@ void __ofono_emulator_slc_condition(struct ofono_emulator *em,
 					enum ofono_emulator_slc_condition cond);
 
 #include <ofono/gnss.h>
-#include <ofono/cdma-sms.h>
-#include <ofono/cdma-netreg.h>
-
-#include <ofono/cdma-provision.h>
-ofono_bool_t __ofono_cdma_provision_get_name(const char *sid, char **name);
 
 #include <ofono/private-network.h>
 
